/*
    Melody maid
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __ICONS_H__
#define __ICONS_H__


#include "mmaid.h"


G_BEGIN_DECLS


/******************************************************************************
*                                                                             *
* ja:アイコン                                                                 *
*                                                                             *
******************************************************************************/
extern const gchar *mmaid16_xpm[];
extern const gchar *mmaid24_xpm[];
extern const gchar *mmaid32_xpm[];
extern const gchar *mmaid48_xpm[];
extern const gchar *export16_xpm[];
extern const gchar *export24_xpm[];
extern const gchar *root16_xpm[];
extern const gchar *root24_xpm[];
#if ! GTK_CHECK_VERSION(2,6,0)
extern const gchar *edit16_xpm[];
extern const gchar *edit24_xpm[];
#endif /* not GTK_CHECK_VERSION(2,6,0) */
extern const gchar *search16_xpm[];
extern const gchar *search24_xpm[];
#if ! GTK_CHECK_VERSION(2,10,0)
extern const gchar *select_all16_xpm[];
extern const gchar *select_all24_xpm[];
#endif /* not GTK_CHECK_VERSION(2,10,0) */
extern const gchar *genre16_xpm[];
extern const gchar *genre24_xpm[];
extern const gchar *character16_xpm[];
extern const gchar *character24_xpm[];
extern const gchar *process16_xpm[];
extern const gchar *process24_xpm[];
#if ! GTK_CHECK_VERSION(2,6,0)
extern const gchar *about16_xpm[];
extern const gchar *about24_xpm[];
extern const gchar *media_play16_xpm[];
extern const gchar *media_play24_xpm[];
extern const gchar *media_stop16_xpm[];
extern const gchar *media_stop24_xpm[];
#endif /* not GTK_CHECK_VERSION(2,6,0) */


G_END_DECLS


#endif /* __ICONS_H__ */
